package com.glxp.mipsdl.controller;

import com.glxp.mipsdl.client.ClientProcessor;
import com.glxp.mipsdl.client.pzh.PzhzdClient;
import com.glxp.mipsdl.req.base.*;
import com.glxp.mipsdl.req.pzh.USignRequest;
import com.glxp.mipsdl.res.BaseResponse;
import com.glxp.mipsdl.util.DictUtl;
import com.glxp.mipsdl.util.ResultVOUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 提供给UDI管理系统的接口
 */
@RestController
public class UdiWmsController {

    @Resource
    private PzhzdClient pzhzdClient;

    /**
     * 获取第三方系统往来单位信息接口
     *
     * @param udiwmsUnitRequest
     * @return
     */
    @PostMapping("/udiwms/erp/getUnits")
    public BaseResponse getUnits(@RequestBody UdiwmsUnitRequest udiwmsUnitRequest) {
        return ClientProcessor.getHttpClient().getUnit(udiwmsUnitRequest);
    }

    /**
     * 获取第三方系统产品信息接口
     *
     * @param udiwmsProductRequest
     * @return
     */
    @PostMapping("/udiwms/erp/getProducts")
    public BaseResponse getProducts(@RequestBody UdiwmsProductRequest udiwmsProductRequest) {
        return ClientProcessor.getHttpClient().getProducts(udiwmsProductRequest);
    }

    /**
     * 获取仓库信息接口
     *
     * @param udiwmsWarehouseRequest
     * @return
     */
    @PostMapping("/udiwms/erp/getWarehouse")
    public BaseResponse getWarehouse(@RequestBody UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        return ClientProcessor.getHttpClient().getWarehouse(udiwmsWarehouseRequest);
    }

    /**
     * 获取单据信息接口
     *
     * @param udiwmsOrderQueryRequest
     * @return
     */
    @PostMapping("/udiwms/erp/getOrders")
    public BaseResponse getOrders(@RequestBody UdiwmsOrderQueryRequest udiwmsOrderQueryRequest) {
        return ClientProcessor.getHttpClient().getOrders(udiwmsOrderQueryRequest);
    }

    /**
     * 获取单据类型接口
     *
     * @param udiwmsBusTypeRequest
     * @return
     */
    @PostMapping("/udiwms/erp/getOrderType")
    public BaseResponse getOrderTypes(@RequestBody UdiwmsBusTypeRequest udiwmsBusTypeRequest) {
        return ClientProcessor.getHttpClient().getOrderTypes(udiwmsBusTypeRequest);
    }

    /**
     * 提交单据接口
     *
     * @param udiwmsOrderRequest
     * @return
     */
    @PostMapping("/udiwms/erp/submitOrders")
    public BaseResponse submitOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        return ClientProcessor.getHttpClient().submitOrders(udiwmsOrderRequest);
    }

    /**
     * 获取库存产品信息接口
     *
     * @param udiwmsInvProductsRequest
     * @return
     */
    @PostMapping("/udiwms/erp/inv/getInvProduct")
    public BaseResponse getInvProduct(@RequestBody UdiwmsInvProductsRequest udiwmsInvProductsRequest) {
        return ClientProcessor.getHttpClient().getInvProducts(udiwmsInvProductsRequest);
    }

    /**
     * 提交产品到第三方系统接口
     *
     * @param udiwmsAddProductsRequest
     * @return
     */
    @PostMapping("/udiwms/erp/post/product")
    public BaseResponse postProduct(@RequestBody UdiwmsAddProductsRequest udiwmsAddProductsRequest) {
        return ClientProcessor.getHttpClient().submitProducts(udiwmsAddProductsRequest);
    }

    /**
     * 添加第三方系统往来单位信息
     *
     * @param udiwmsAddUnitRequest
     * @return
     */
    @PostMapping("/udiwms/erp/post/unit")
    public BaseResponse postUnit(@RequestBody UdiwmsAddUnitRequest udiwmsAddUnitRequest) {
        return ClientProcessor.getHttpClient().submitUnit(udiwmsAddUnitRequest);
    }

    @PostMapping("/udiwms/erp/testThirdSys")
    public BaseResponse testThirdSys() {
        return ClientProcessor.getHttpClient().testConnect();
    }


    @PostMapping("/udiwms/erp/testLocal")
    public BaseResponse testLocal() {
        return ResultVOUtils.success("连接第三方服务成功！");
    }


    //片仔癀用友U8专属接口

    /**
     * 提交采购计划
     *
     * @return
     */
    @PostMapping("/udiwms/erp/order/postOrder")
    public BaseResponse postOrder(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (!DictUtl.CURRENT_HOSP_CODE.equals("100002")) {
            return ResultVOUtils.error(500, "未设置系统版本");
        }
        return pzhzdClient.postOrder(udiwmsOrderRequest);
    }

    /**
     * 获取现存量接口
     *
     * @param udiwmsInvProductsRequest
     * @return
     */
    @GetMapping("/udiwms/erp/getOnhand")
    public BaseResponse getOnHand(@RequestBody UdiwmsInvProductsRequest udiwmsInvProductsRequest) {
        if (!DictUtl.CURRENT_HOSP_CODE.equals("100002")) {
            return ResultVOUtils.error(500, "未设置系统版本");
        }
        return pzhzdClient.getOnHand(udiwmsInvProductsRequest);
    }

    /**
     * 签字ERP订单接口
     *
     * @param signRequest
     * @return
     */
    @PostMapping("/udiwms/erp/signBill")
    public BaseResponse signBill(@RequestBody USignRequest signRequest) {
        if (!DictUtl.CURRENT_HOSP_CODE.equals("100002")) {
            return ResultVOUtils.error(500, "未设置系统版本");
        }
        return pzhzdClient.signBill(signRequest);
    }

    //修改ERP订单接口
    @PostMapping("/udiwms/erp/modifyBill")
    public BaseResponse modifyBill(@RequestBody UdiwmsPostBillRequest udiwmsPostBillRequest) {
        if (!DictUtl.CURRENT_HOSP_CODE.equals("100002")) {
            return ResultVOUtils.error(500, "未设置系统版本");
        }
        return pzhzdClient.modifyBill(udiwmsPostBillRequest);
    }

}
